#
# Conditional build:
%bcond_with	zlib	# zlib compression support (may reduce security, see CRIME)
#
%define		sname	mbedtls
#
Summary:	Light-weight cryptographic and SSL/TLS library
Summary(pl.UTF-8):	Lekka biblioteka kryptograficzna oraz SSL/TLS
Name:		%{sname}2
Version:	2.28.3
Release:	2
License:	GPL v2+
Group:		Libraries
#Source0Download: https://github.com/ARMmbed/mbedtls/releases
Source0:	https://github.com/ARMmbed/mbedtls/archive/v%{version}/%{sname}-%{version}.tar.gz
# Source0-md5:	7e1b09243447a0378a78dd5469b68415
Patch0:		%{sname}-config-dtls-srtp.patch
URL:		https://www.trustedfirmware.org/projects/mbed-tls/
BuildRequires:	cmake >= 2.8.12
BuildRequires:	doxygen
BuildRequires:	rpm-build >= 4.6
BuildRequires:	rpmbuild(macros) >= 1.605
%{?with_zlib:BuildRequires:	zlib-devel}
BuildRoot:	%{tmpdir}/%{name}-%{version}-root-%(id -u -n)

# some false positives for format-truncation(?)
# for stringop-overflow see library/ssl_tls.c /stringop-overflow (workaround no longer works with gcc 11)
# maybe-uninitialized fails in tests/suites/test_suite_ssl.function only on i686 builder(???)
%define		specflags -Wno-error=format-truncation -Wno-error=stringop-overflow -Wno-error=maybe-uninitialized

%description
mbedTLS is a light-weight open source cryptographic and SSL/TLS
library written in C. mbedTLS makes it easy for developers to include
cryptographic and SSL/TLS capabilities in their (embedded)
applications with as little hassle as possible.

%description -l pl.UTF-8
mbedTLS to lekka, mająca otwarte źródła biblioteka kryptograficzna
oraz SSL/TLS napisana w C. mbedTLS ułatwia programistom dołączanie
funkcji kryptograficznych i SSL/TLS do swoich (wbudowanych) aplikacji
przy jak najmniejszym narzucie.

%package devel
Summary:	Development files for mbedTLS
Summary(pl.UTF-8):	Pliki programistyczne biblioteki mbedTLS
Group:		Development/Libraries
Requires:	%{name} = %{version}-%{release}
Conflicts:	%{sname}-devel

%description devel
This package contains the header files for developing applications
that use mbedTLS.

%description devel -l pl.UTF-8
Ten pakiet zawiera pliki nagłówkowe do tworzenia aplikacji
wykorzystujących bibliotekę mbedTLS.

%package static
Summary:	Static mbedTLS library
Summary(pl.UTF-8):	Statyczna biblioteka mbedTLS
Group:		Development/Libraries
Requires:	%{name}-devel = %{version}-%{release}
Conflicts:	%{sname}-static

%description static
Static mbedTLS library.

%description static -l pl.UTF-8
Statyczna biblioteka mbedTLS.

%package apidocs
Summary:	API documentation for mbedTLS library
Summary(pl.UTF-8):	Dokumentacja API biblioteki mbedTLS
Group:		Documentation
BuildArch:	noarch

%description apidocs
API documentation for mbedTLS library.

%description apidocs -l pl.UTF-8
Dokumentacja API biblioteki mbedTLS.

%prep
%setup -q -n %{sname}-%{version}
%patch0 -p1

%build
install -d build
cd build
%cmake .. \
	-DLIB_INSTALL_DIR:PATH=%{_libdir} \
	%{?with_zlib:-DENABLE_ZLIB_SUPPORT=ON} \
	-DUSE_SHARED_MBEDTLS_LIBRARY=ON

%{__make}
%{__make} apidoc

%if %{with tests}
# Tests are not stable on 64-bit
ctest --output-on-failure
%endif

%install
rm -rf $RPM_BUILD_ROOT

%{__make} -C build install \
	DESTDIR=$RPM_BUILD_ROOT

install -d $RPM_BUILD_ROOT%{_libexecdir}
%{__mv} $RPM_BUILD_ROOT%{_bindir} $RPM_BUILD_ROOT%{_libexecdir}/%{name}

%clean
rm -rf $RPM_BUILD_ROOT

%post	-p /sbin/ldconfig
%postun	-p /sbin/ldconfig

%files
%defattr(644,root,root,755)
%doc ChangeLog LICENSE README.md
%attr(755,root,root) %{_libdir}/libmbedcrypto.so.*.*.*
%attr(755,root,root) %ghost %{_libdir}/libmbedcrypto.so.7
%attr(755,root,root) %{_libdir}/libmbedtls.so.*.*.*
%attr(755,root,root) %ghost %{_libdir}/libmbedtls.so.14
%attr(755,root,root) %{_libdir}/libmbedx509.so.*.*.*
%attr(755,root,root) %ghost %{_libdir}/libmbedx509.so.1
%dir %{_libexecdir}/%{name}
%attr(755,root,root) %{_libexecdir}/%{name}/benchmark
%attr(755,root,root) %{_libexecdir}/%{name}/cert_app
%attr(755,root,root) %{_libexecdir}/%{name}/cert_req
%attr(755,root,root) %{_libexecdir}/%{name}/cert_write
%attr(755,root,root) %{_libexecdir}/%{name}/crl_app
%attr(755,root,root) %{_libexecdir}/%{name}/crypt_and_hash
%attr(755,root,root) %{_libexecdir}/%{name}/crypto_examples
%attr(755,root,root) %{_libexecdir}/%{name}/dh_client
%attr(755,root,root) %{_libexecdir}/%{name}/dh_genprime
%attr(755,root,root) %{_libexecdir}/%{name}/dh_server
%attr(755,root,root) %{_libexecdir}/%{name}/dtls_client
%attr(755,root,root) %{_libexecdir}/%{name}/dtls_server
%attr(755,root,root) %{_libexecdir}/%{name}/ecdh_curve25519
%attr(755,root,root) %{_libexecdir}/%{name}/ecdsa
%attr(755,root,root) %{_libexecdir}/%{name}/gen_entropy
%attr(755,root,root) %{_libexecdir}/%{name}/gen_key
%attr(755,root,root) %{_libexecdir}/%{name}/gen_random_ctr_drbg
%attr(755,root,root) %{_libexecdir}/%{name}/gen_random_havege
%attr(755,root,root) %{_libexecdir}/%{name}/generic_sum
%attr(755,root,root) %{_libexecdir}/%{name}/hello
%attr(755,root,root) %{_libexecdir}/%{name}/key_app
%attr(755,root,root) %{_libexecdir}/%{name}/key_app_writer
%attr(755,root,root) %{_libexecdir}/%{name}/key_ladder_demo
%attr(755,root,root) %{_libexecdir}/%{name}/key_ladder_demo.sh
%attr(755,root,root) %{_libexecdir}/%{name}/load_roots
%attr(755,root,root) %{_libexecdir}/%{name}/mini_client
%attr(755,root,root) %{_libexecdir}/%{name}/mpi_demo
%attr(755,root,root) %{_libexecdir}/%{name}/pem2der
%attr(755,root,root) %{_libexecdir}/%{name}/pk_decrypt
%attr(755,root,root) %{_libexecdir}/%{name}/pk_encrypt
%attr(755,root,root) %{_libexecdir}/%{name}/pk_sign
%attr(755,root,root) %{_libexecdir}/%{name}/pk_verify
%attr(755,root,root) %{_libexecdir}/%{name}/psa_constant_names
%attr(755,root,root) %{_libexecdir}/%{name}/query_compile_time_config
%attr(755,root,root) %{_libexecdir}/%{name}/req_app
%attr(755,root,root) %{_libexecdir}/%{name}/rsa_decrypt
%attr(755,root,root) %{_libexecdir}/%{name}/rsa_encrypt
%attr(755,root,root) %{_libexecdir}/%{name}/rsa_genkey
%attr(755,root,root) %{_libexecdir}/%{name}/rsa_sign
%attr(755,root,root) %{_libexecdir}/%{name}/rsa_sign_pss
%attr(755,root,root) %{_libexecdir}/%{name}/rsa_verify
%attr(755,root,root) %{_libexecdir}/%{name}/rsa_verify_pss
%attr(755,root,root) %{_libexecdir}/%{name}/selftest
%attr(755,root,root) %{_libexecdir}/%{name}/ssl_client1
%attr(755,root,root) %{_libexecdir}/%{name}/ssl_client2
%attr(755,root,root) %{_libexecdir}/%{name}/ssl_context_info
%attr(755,root,root) %{_libexecdir}/%{name}/ssl_fork_server
%attr(755,root,root) %{_libexecdir}/%{name}/ssl_mail_client
%attr(755,root,root) %{_libexecdir}/%{name}/ssl_pthread_server
%attr(755,root,root) %{_libexecdir}/%{name}/ssl_server
%attr(755,root,root) %{_libexecdir}/%{name}/ssl_server2
%attr(755,root,root) %{_libexecdir}/%{name}/strerror
%attr(755,root,root) %{_libexecdir}/%{name}/udp_proxy
%attr(755,root,root) %{_libexecdir}/%{name}/zeroize

%files devel
%defattr(644,root,root,755)
%attr(755,root,root) %{_libdir}/libmbedcrypto.so
%attr(755,root,root) %{_libdir}/libmbedtls.so
%attr(755,root,root) %{_libdir}/libmbedx509.so
%{_includedir}/mbedtls
%{_includedir}/psa

%files static
%defattr(644,root,root,755)
%{_libdir}/libmbedcrypto.a
%{_libdir}/libmbedtls.a
%{_libdir}/libmbedx509.a

%files apidocs
%defattr(644,root,root,755)
%doc apidoc/{search,*.css,*.html,*.js,*.png}
%changelog
* Fri Apr 07 2023 PLD Linux Team <feedback@pld-linux.org>
- For complete changelog see: http://git.pld-linux.org/?p=packages/mbedtls.git;a=log;h=MBEDTLS_2

* Fri Apr 07 2023 Jakub Bogusz <qboosh@pld-linux.org> 9e96f09
- typo, release 2

* Fri Apr 07 2023 Jakub Bogusz <qboosh@pld-linux.org> acb38c1
- use _libexecdir for tools

* Fri Apr 07 2023 Jakub Bogusz <qboosh@pld-linux.org> d2fc224
- updated to 2.28.3 (fixes CVE-2022-35409, new libmbedcrypto/libmbedtls sonames)

* Tue Apr 26 2022 Arkadiusz Miśkiewicz <arekm@maven.pl> 04d9bbf
- Keep mbedtls 2.x as mbedtls2.

* Sun Jun 13 2021 Jakub Bogusz <qboosh@pld-linux.org> 543346b
- added config-dtls-srtp patch (enable MBEDTLS_SSL_DTLS_SRTP feature for linphone etc.); release 2

* Sun Jun 13 2021 Jakub Bogusz <qboosh@pld-linux.org> 07b0e16
- typo

* Sun Jun 13 2021 Jakub Bogusz <qboosh@pld-linux.org> 645d2dc
- disable one more -Werror failing build on th-i686

* Sun Jun 13 2021 Jakub Bogusz <qboosh@pld-linux.org> 9735fbf
- disable -Werror=stringop-overflow (build failed with gcc 11)

* Sat Jun 12 2021 Jakub Bogusz <qboosh@pld-linux.org> 59cd7fb
- updated to 2.26.0 (new sonames)

* Tue Mar 16 2021 Jakub Bogusz <qboosh@pld-linux.org> 9874b67
- new URLs, updated to 2.6.10

* Mon May 11 2020 Jakub Bogusz <qboosh@pld-linux.org> af4afdc
- updated to 2.16.6 (fixes CVE-2020-10932)

* Mon Apr 22 2019 Jakub Bogusz <qboosh@pld-linux.org> 628fc69
- updated to 2.16.1 (note: new libmbedcrypto,libmbedtls sonames)

* Sat Nov 25 2017 Jakub Bogusz <qboosh@pld-linux.org> 875e57b
- updated to 2.6.0
- separated -apidocs

* Thu Aug 04 2016 Jakub Bogusz <qboosh@pld-linux.org> e2bfa2a
- updated to 2.3.0
- removed obsolete x32 patch

* Sun Mar 06 2016 Jakub Bogusz <qboosh@pld-linux.org> a295c65
- updated to 2.2.1 (fixes double free issues)

* Mon Nov 09 2015 Jakub Bogusz <qboosh@pld-linux.org> 95cbb03
- updated to 2.2.0

* Sun Jul 19 2015 Jakub Bogusz <qboosh@pld-linux.org> 64c8d75
- updated to 2.0.0

* Tue Jun 23 2015 Jakub Bogusz <qboosh@pld-linux.org> bf36c92
- updated to 1.3.11

* Tue May 19 2015 Jakub Bogusz <qboosh@pld-linux.org> e64b4bc
- merged x32 patch from polarssl; release 2

* Sun May 17 2015 Jakub Bogusz <qboosh@pld-linux.org> a3f8074
- new, continuation of polarssl

